@@ -45,7 +45,9 @@ typedef enum {
   EPHY_PERMISSION_TYPE_SHOW_ADS,
   EPHY_PERMISSION_TYPE_AUTOPLAY_POLICY,
   EPHY_PERMISSION_TYPE_ACCESS_WEBCAM_AND_MICROPHONE,
-  EPHY_PERMISSION_TYPE_COOKIES,
+  EPHY_PERMISSION_TYPE_WEBSITE_DATA_ACCESS,
+  EPHY_PERMISSION_TYPE_CLIPBOARD,
+  EPHY_PERMISSION_TYPE_ACCESS_DISPLAY
 } EphyPermissionType;
 
 EphyPermissionsManager *ephy_permissions_manager_new            (void);
