@@ -21,6 +21,7 @@
 #pragma once
 
 #include "ephy-bookmark.h"
+#include "ephy-link.h"
 
 #include <gtk/gtk.h>
 
@@ -28,7 +29,7 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_BOOKMARK_ROW (ephy_bookmark_row_get_type ())
 
-G_DECLARE_FINAL_TYPE (EphyBookmarkRow, ephy_bookmark_row, EPHY, BOOKMARK_ROW, GtkListBoxRow)
+G_DECLARE_FINAL_TYPE (EphyBookmarkRow, ephy_bookmark_row, EPHY, BOOKMARK_ROW, AdwActionRow)
 
 GtkWidget           *ephy_bookmark_row_new              (EphyBookmark *bookmark);
 
@@ -36,4 +37,10 @@ EphyBookmark        *ephy_bookmark_row_get_bookmark     (EphyBookmarkRow *self);
 
 const char          *ephy_bookmark_row_get_bookmark_url (EphyBookmarkRow *self);
 
+void                 ephy_bookmark_row_open             (EphyBookmarkRow *self,
+                                                         EphyLinkFlags    flags);
+
+void                 ephy_bookmark_row_set_movable     (EphyBookmarkRow *self,
+                                                        gboolean         movable);
+
 G_END_DECLS
