@@ -20,16 +20,21 @@
 
 #pragma once
 
-#include <gtk/gtk.h>
+#include <adwaita.h>
 
 #include "ephy-history-service.h"
+#include "ephy-window.h"
 
 G_BEGIN_DECLS
 
 #define EPHY_TYPE_HISTORY_DIALOG (ephy_history_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (EphyHistoryDialog, ephy_history_dialog, EPHY, HISTORY_DIALOG, GtkWindow)
+G_DECLARE_FINAL_TYPE (EphyHistoryDialog, ephy_history_dialog, EPHY, HISTORY_DIALOG, AdwDialog)
 
-GtkWidget      *ephy_history_dialog_new        (EphyHistoryService *history_service);
+EphyWindow     *ephy_history_dialog_get_parent_window (EphyHistoryDialog  *self);
+void            ephy_history_dialog_set_parent_window (EphyHistoryDialog  *self,
+                                                       EphyWindow         *window);
+
+GtkWidget      *ephy_history_dialog_new               (EphyHistoryService *history_service);
 
 G_END_DECLS
