@@ -921,13 +921,16 @@ save_session_sync (GTask        *task,
                    GCancellable *cancellable)
 {
   SaveData *data = (SaveData *)g_task_get_task_data (task);
-  xmlBufferPtr buffer;
-  xmlTextWriterPtr writer;
+  xmlOutputBufferPtr buffer;
+  xmlTextWriterPtr writer = NULL;
   GList *w;
   int ret = -1;
 
-  buffer = xmlBufferCreate ();
-  writer = xmlNewTextWriterMemory (buffer, 0);
+  buffer = xmlAllocOutputBuffer (NULL);
+  if (buffer == NULL)
+    goto out;
+
+  writer = xmlNewTextWriter (buffer);
   if (writer == NULL)
     goto out;
 
@@ -963,29 +966,21 @@ save_session_sync (GTask        *task,
 
   ret = xmlTextWriterEndDocument (writer);
 
-out:
-  if (writer)
-    xmlFreeTextWriter (writer);
-
   if (ret >= 0) {
-    GError *error = NULL;
-    GFile *session_file;
+    g_autoptr (GError) error = NULL;
+    g_autoptr (GFile) session_file = NULL;
 
     session_file = get_session_file (SESSION_STATE);
-
     if (!g_file_replace_contents (session_file,
-                                  (const char *)buffer->content,
-                                  buffer->use,
+                                  (const char *)xmlBufContent (buffer->buffer),
+                                  xmlBufUse (buffer->buffer),
                                   NULL, TRUE, 0, NULL, NULL, &error)) {
       g_warning ("Error saving session: %s", error->message);
-      g_error_free (error);
     }
-
-    g_object_unref (session_file);
   }
 
-  xmlBufferFree (buffer);
-
+out:
+  g_clear_pointer (&writer, xmlFreeTextWriter);
   g_task_return_boolean (task, TRUE);
 
   STOP_PROFILER ("Saving session")
@@ -1339,6 +1334,18 @@ session_end_element (GMarkupParseContext  *ctx,
       return;
     }
 
+    if (context->is_first_tab) {
+      EphyEmbed *embed;
+      EphyWebView *web_view;
+
+      /* No tabs were restored from session state. */
+
+      embed = ephy_shell_new_tab (ephy_shell_get_default (),
+                                  context->window, NULL, 0);
+      web_view = ephy_embed_get_web_view (embed);
+      ephy_web_view_load_homepage (web_view);
+    }
+
     tab_view = ephy_window_get_tab_view (context->window);
     if (context->active_tab < ephy_tab_view_get_n_pages (tab_view))
       ephy_tab_view_select_nth_page (tab_view, context->active_tab);
